@@ -2,22 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 2011 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2010 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2009 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2008 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2007 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2006 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -46,7 +31,7 @@
 
 
 #if !defined(COMPRESS_ID)
-#define COMPRESS_ID     LZO_CPP_ECONCAT2(DD_BITS,CLEVEL)
+#define COMPRESS_ID     LZO_PP_ECONCAT2(DD_BITS,CLEVEL)
 #endif
 
 
@@ -58,10 +43,10 @@
 ************************************************************************/
 
 #define LZO_COMPRESS \
-    LZO_CPP_ECONCAT3(lzo1c_,COMPRESS_ID,_compress)
+    LZO_PP_ECONCAT3(lzo1c_,COMPRESS_ID,_compress)
 
 #define LZO_COMPRESS_FUNC \
-    LZO_CPP_ECONCAT3(_lzo1c_,COMPRESS_ID,_compress_func)
+    LZO_PP_ECONCAT3(_lzo1c_,COMPRESS_ID,_compress_func)
 
 
 
@@ -79,6 +64,5 @@ LZO_COMPRESS ( const lzo_bytep in,  lzo_uint  in_len,
     return _lzo1c_do_compress(in,in_len,out,out_len,wrkmem,do_compress);
 }
 
-/*
-vi:ts=4:et
-*/
+
+/* vim:set ts=4 sw=4 et: */
