@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2014 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@
 #define __LZO_CONFIG1_H 1
 
 #include "lzo_conf.h"
-#include "lzo/lzo1.h"
+#include <lzo/lzo1.h>
 
 #define LZO_NO_R1 1
 #include "config1a.h"
@@ -43,7 +43,4 @@
 #endif /* already included */
 
 
-/*
-vi:ts=4:et
-*/
-
+/* vim:set ts=4 sw=4 et: */
