@@ -2,21 +2,13 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License,
-   version 2, as published by the Free Software Foundation.
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2 of
+   the License, or (at your option) any later version.
 
    The LZO library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -41,7 +33,7 @@
 
 
 #ifndef __LZO_DEFS_H
-#define __LZO_DEFS_H
+#define __LZO_DEFS_H 1
 
 #ifdef __cplusplus
 extern "C" {
@@ -113,7 +105,7 @@ extern "C" {
 
 
 #define __MIN_OFFSET(bits)  1
-#define __MAX_OFFSET(bits)  LZO_LSIZE(bits)
+#define __MAX_OFFSET(bits)  LZO_SIZE(bits)
 
 #define M1_MIN_OFFSET       __MIN_OFFSET(M1X_BITS)
 #define M2_MIN_OFFSET       __MIN_OFFSET(M2X_BITS)
@@ -334,7 +326,5 @@ extern "C" {
 
 #endif /* already included */
 
-/*
-vi:ts=4:et
-*/
 
+/* vim:set ts=4 sw=4 et: */
